package java112.analyzer;

import java.util.*;
import java.io.*;
/**
 * Processes individual text tokens and stores a list of unique values
 * where word length is greater than or equal to minimum word length.
 * Writes a report listing one unique token per line.
 * @author Brian Manning
 */
public class BigWordAnalyzer extends UniqueTokenAnalyzer implements Analyzer {

    //Stores a list of unique big word text tokens.
    private Set<String> bigWords;

    //Integer value for minimum length to be considered a big word.
    private int minimumWordLength;

    //Properties file for this analyzer.
    private Properties properties;

    /**
     * empty constructor for BigWordAnalyzer
     */
    public BigWordAnalyzer() {

    }

    /**
     * Constructor for BigWordAnalyzer, calls super constructor and
     * instantiates instance varialbes. Retrieves bigword minimum length from properties
     * @param properties Properties - Properties file values for this analyzer.
     */
    public BigWordAnalyzer(Properties properties) {
        super(properties);
        this.properties = properties;
        bigWords = getUniqueTokensList();
        minimumWordLength = Integer.parseInt(
                properties.getProperty("bigwords.minimum.length"));
    }

    /**
     * Accessor for the getBigWords instance variable.
     * @return getBigWords Set. A list of all big word unique tokens.
     */
    public Set<String> getBigWords() {
        return bigWords;
    }

    /**
     * Processes a single token by testing length and passing to super
     * processToken method.
     * @param token String - a single text token.
     */
    public void processToken(String token) {
        if (token.length() >= minimumWordLength) {
            super.processToken(token);
        }
    }

    /**
     * Retrieves values from properties for path to output file.
     * Overrides super method to allow control of file path.
     * @return outputFilePath String - Path of the output file.
     */
    public String getOutputFilePath() {
        return properties.getProperty("output.dir")
                + properties.getProperty("output.file.bigwords");
    }

}
