package java112.project2;

import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.annotation.*;


@WebServlet(name = "PropertiesServlet", urlPatterns = { "/propertiesTwo" } )
/**
 * PropertiesServlet This servlet displays the authors name, course and
 * section. It draws values from the project2.properties file to populate
 * an html table.
 * @author Brian Manning
 */
public class PropertiesServlet extends HttpServlet {

    //Properties for this servlet.
    private Properties properties;

    /**
     *  Handles HTTP GET requests.
     *
     *@param  request                   the HttpServletRequest object
     *@param  response                   the HttpServletResponse object
     *@exception  ServletException  if there is a Servlet failure
     *@exception  IOException       if there is an IO failure
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
                throws ServletException, IOException {
        response.setContentType("text/html");
        // set the response type before sending data
        PrintWriter out = response.getWriter();
        out.print("<HTML>");
        out.print("<HEAD><TITLE>Brian Manning - PropertiesServlet</TITLE></HEAD>");
        out.print("<BODY>");
        out.print("<table>");

        out.print("<h1>PropertiesServlet</h1>");

        out.print("<tr><td>Name:</td>");
        out.print("<td>");
        out.print(properties.getProperty("author"));
        out.print("</td></tr>");

        out.print("<tr><td>Email:</td>");
        out.print("<td>");
        out.print(properties.getProperty("author.email.address"));
        out.print("</td></tr>");

        out.print("<tr><td>Course:</td>");
        out.print("<td>");
        out.print(properties.getProperty("course") + " "
                + properties.getProperty("course.section"));
        out.print("</td></tr>");

        out.print("<tr><td>Instructor:</td>");
        out.print("<td>");
        out.print(properties.getProperty("course.instructor"));
        out.print("</td></tr>");

        out.print("<tr><td colspan='2'>");
        out.print(properties.getProperty("description"));
        out.print("</td></tr>");

        out.print("</table>");

        out.print("<p><a href='/java112'>Home</a></p>");
        out.print("</BODY>");
        out.print("</HTML>");
        log("doGet complete");
        out.close();
    }

    /**
     * Loads the properties on servlet init
     */
    public void init() throws ServletException {
        loadProperties("/project2.properties");
    }

    /**
     * Loads the properties file for use with all analyzers
     * @param propertiesFilePath String - path to properties file
     */
    public void loadProperties(String propertiesFilePath)  {
        properties = new Properties();
        try {
            properties.load(this.getClass().getResourceAsStream(propertiesFilePath));
        }
        catch(IOException ioe) {
            System.out.println("Can't load the properties file");
            ioe.printStackTrace();
        }
        catch(Exception e) {
            System.out.println("Problem: " + e);
            e.printStackTrace();
        }
    }

}

