package java112.project3;

import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.annotation.*;


@WebServlet(
    name = "project3PropertiesServlet",
    urlPatterns = { "/project3-properties" }
)
/**
 * Reads values from a properties file and add them to the request.
 * Forwards request to a jsp page for display.
 * @author Brian Manning
 */
public class PropertiesServlet extends HttpServlet {
    // Properties for this servlet.
    private Properties properties;


    /**
     * Adds properties retrieved from file to the request and forwards to
     *  and forwards it to PropertiesServlet.jsp for display.
     *@param  request                   the HttpServletRequest object
     *@param  response                   the HttpServletResponse object
     *@exception  ServletException  if there is a Servlet failure
     *@exception  IOException       if there is an IO failure
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        request.setAttribute("properties", properties);
        String url = "/PropertiesServlet.jsp";
        RequestDispatcher dispatcher = 
                getServletContext().getRequestDispatcher(url);
        dispatcher.forward(request, response);
    }

    /**
     * Loads properties on servlet init
     */
    public void init() throws ServletException {
        loadProperties("/project3.properties");
    }

    /**
     * Loads the properties file for project 3
     * @param propertiesFilePath String - path to properties file
     */
    public void loadProperties(String propertiesFilePath) {
        properties = new Properties();
        try {
            properties.load(this.getClass().getResourceAsStream(propertiesFilePath));
        } catch (IOException ioe) {
            System.out.println("Can't load the properties file");
            ioe.printStackTrace();
        } catch (Exception e) {
            System.out.println("Problem: " + e);
            e.printStackTrace();
        }
    }

}
