package java112.project4;

import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.annotation.*;
import java112.employee.*;


@WebServlet(
    name = "employeeAddActionServlet",
    urlPatterns = { "/employeeAddActionServlet" }
)
/**
 * EmployeeAddActionServlet handles form input for DB insert.
 * @author Brian Manning
 */
public class EmployeeAddActionServlet extends HttpServlet {

    /**
     * Handles user form input. Validates fields and passes values to
     * application level EmployeeDirectory object in servlet context for
     * processing
     *@param  request                   the HttpServletRequest object
     *@param  response                   the HttpServletResponse object
     *@exception  ServletException  if there is a Servlet failure
     *@exception  IOException       if there is an IO failure
     */
    public void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {

        String url = "/java112/employeeAddServlet";
        EmployeeDirectory employeeDirectory = (EmployeeDirectory) 
                getServletContext().getAttribute("employeeDirectory");
        HttpSession session = request.getSession();
        validateAllFields(request);

        if (!(boolean) session.getAttribute("inputHasErrors")) {
            String employeeId = request.getParameter("employeeId");
            String firstName = request.getParameter("firstName");
            String lastName = request.getParameter("lastName");
            String socialSecurityNumber =
                    request.getParameter("socialSecurityNumber");
            String department = request.getParameter("department");
            String roomNumber = request.getParameter("roomNumber");
            String phoneNumber = request.getParameter("phoneNumber");
            String formAddMessage = employeeDirectory.addEmployee (
                        firstName, lastName, socialSecurityNumber,
                        department, roomNumber, phoneNumber);
            session.setAttribute("formAddMessage", formAddMessage);
        }

        response.sendRedirect(url);
    }

    /**
     * Loops through enumeration of all form parameter names. Tests each
     * for null or empty.and generates and error message. Results added to
     * user sessions
     * processing
     *@param  request - the HttpServletRequest object
     */
    private void validateAllFields(HttpServletRequest request) {
        HttpSession session = request.getSession();
        List<String> formErrorMessage = new ArrayList<String>();
        boolean inputHasErrors = false;
        Enumeration parameterNames = request.getParameterNames();
        String parameterName;
        String parameterValue;

        while (parameterNames.hasMoreElements()) {
            parameterName = (String) parameterNames.nextElement();
            parameterValue = request.getParameter(parameterName);
            if (parameterValue == null || parameterValue.isEmpty()) {
                inputHasErrors = true;
                formErrorMessage.add(parameterName + " is required.");
            }
        }
        session.setAttribute("inputHasErrors", inputHasErrors);
        session.setAttribute("formErrorMessage", formErrorMessage);
    }
}
