package java112.project4;

import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.annotation.*;
import java112.employee.*;


@WebServlet(
    name = "employeeSearchResultsServlet",
    urlPatterns = { "/employeeSearchResultsServlet" }
)
/**
 * Handles form input for queries of the employees tables. Passes to
 * EmployeeDirectory for query processing. Forwards to search results jsp
 * page for display.
 * @author Brian Manning
 */
public class EmployeeSearchResultsServlet extends HttpServlet {

    /**
     * Validates form input and passes to employee directory for processing
     * or back to search form on input error. Assigns form values to the
     * search objct for storage. Adds search object to user session for display.
     *@param  request                   the HttpServletRequest object
     *@param  response                   the HttpServletResponse object
     *@exception  ServletException  if there is a Servlet failure
     *@exception  IOException       if there is an IO failure
     */
    public void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {

        Search search = null;
        String url;
        String searchTerm = (String) request.getParameter("searchTerm");
        String searchType = (String) request.getParameter("searchType");
        HttpSession session = request.getSession();
        EmployeeDirectory employeeDirectory = (EmployeeDirectory)
                getServletContext().getAttribute("employeeDirectory");

        url = validateForm(request);

        search = employeeDirectory.executeSearch(searchType, searchTerm);

        session.setAttribute("search", search);

        RequestDispatcher dispatcher = getServletContext().getRequestDispatcher(url);

        dispatcher.forward(request, response);
    }

    /**
     * Tests all form input and generates error message.
     * @param  request the HttpServletRequest object
     */
    private String validateForm(HttpServletRequest request) {
        String searchType = request.getParameter("searchType");
        String searchTerm = request.getParameter("searchTerm");
        List<String> formErrorMessage = new ArrayList<String>();
        boolean inputHasErrors = false;

        if (!inputIsValid(searchType)) {
            formErrorMessage.add("Please select a search type.");
            inputHasErrors = true;
        }

        if (!inputIsValid(searchTerm)) {
            formErrorMessage.add("Please enter a search term.");
            inputHasErrors = true;
        }

        request.setAttribute("formErrorMessage", formErrorMessage);

        if (inputHasErrors) {
            return "/employeeSearch.jsp";
        }
        return "/employeeSearchResults.jsp";
    }

    /**
     * Tests a string for null or empty
     * @param  String input - value of form input
     * @return boolean - true if valid, false if null or empty.
     */
    private static boolean inputIsValid(String input) {
        if (input == null || input.isEmpty()) {
            return false;
        }
        return true;
    }

}
